# AXESDN Python SDK

### Requirements

- Python >= 3.7

### Installation

- Install with pip
```
pip install axesdn_sdk
```

### Usage

- [Quick Examples](axesdnSDK/example)

### Changelog

- Detailed changes for each release are documented in the [release notes](CHANGELOG.md)

### License

[Apache-2.0](http://www.apache.org/licenses/LICENSE-2.0)

Copyright (c) 2018-present, AXESDN rights reserved.